@@ -17,13 +17,16 @@ import os
 import shutil
 import six
 from six.moves import configparser
+import subprocess
 import tempfile
-
+import time
 import yaml
 
 from mistral_lib import actions
 from oslo_concurrency import processutils
 
+from tripleo_common.actions import base
+
 
 def write_default_ansible_cfg(work_dir,
                               base_ansible_cfg='/etc/ansible/ansible.cfg'):
@@ -34,6 +37,12 @@ def write_default_ansible_cfg(work_dir,
     config.read(ansible_config_path)
 
     config.set('defaults', 'retry_files_enabled', 'False')
+    config.set('defaults', 'log_path',
+               os.path.join(work_dir, 'ansible.log'))
+
+    # mistral user has no home dir set, so no place to save a known hosts file
+    config.set('ssh_connection', 'ssh_args',
+               '-o UserKnownHostsFile=/dev/null -o StrictHostKeyChecking=no')
 
     with open(ansible_config_path, 'w') as configfile:
         config.write(configfile)
@@ -207,14 +216,15 @@ class AnsibleAction(actions.Action):
                 *command, cwd=self.work_dir,
                 env_variables=env_variables,
                 log_errors=processutils.LogErrors.ALL)
-            return {"stderr": stderr, "stdout": stdout}
+            return {"stderr": stderr, "stdout": stdout,
+                    "log_path": os.path.join(self.work_dir, 'ansible.log')}
         finally:
             # NOTE(flaper87): clean the mess if debug is disabled.
             if not self.verbosity:
                 shutil.rmtree(self.work_dir)
 
 
-class AnsiblePlaybookAction(actions.Action):
+class AnsiblePlaybookAction(base.TripleOAction):
     """Executes ansible playbook"""
 
     def __init__(self, **kwargs):
@@ -248,8 +258,12 @@ class AnsiblePlaybookAction(actions.Action):
         self.skip_tags = self._kwargs_for_run.pop('skip_tags', None)
         self.extra_env_variables = self._kwargs_for_run.pop(
             'extra_env_variables', None)
+        self.queue_name = self._kwargs_for_run.pop('queue_name', None)
+        self.reproduce_command = self._kwargs_for_run.pop(
+            'reproduce_command', True)
 
-        self._work_dir = None
+        self._work_dir = self._kwargs_for_run.pop(
+            'work_dir', None)
 
     @property
     def work_dir(self):
@@ -332,6 +346,14 @@ class AnsiblePlaybookAction(actions.Action):
         self._ssh_private_key = path
         return path
 
+    def format_message(self, lines):
+        return {
+            'body': {
+                'payload': {
+                    'message': ''.join(lines),
+                    'status': 'RUNNING',
+                    'execution': {'id': None}}}}
+
     def run(self, context):
         if 0 < self.verbosity < 6:
             verbosity_option = '-' + ('v' * self.verbosity)
@@ -407,12 +429,104 @@ class AnsiblePlaybookAction(actions.Action):
                     'OS_AUTH_TOKEN': context.auth_token,
                     'OS_PROJECT_NAME': context.project_name})
 
+            command = [str(c) for c in command]
+
+            if self.reproduce_command:
+                command_path = os.path.join(self.work_dir,
+                                            "ansible-playbook-command.sh")
+                with open(command_path, 'w') as f:
+                    f.write('#!/bin/bash\n')
+                    f.write('\n')
+                    for var in env_variables:
+                        f.write('%s="%s"\n' % (var, env_variables[var]))
+                    f.write('\n')
+                    f.write(' '.join(command))
+                    f.write(' $@')
+                    f.write('\n')
+
+                os.chmod(command_path, 0o750)
+
+            if self.queue_name:
+                zaqar = self.get_messaging_client(context)
+                queue = zaqar.queue(self.queue_name)
+                # TODO(d0ugal): We don't have the log errors functionality
+                # that processutils has, do we need to replicate that somehow?
+                process = subprocess.Popen(command, stdout=subprocess.PIPE,
+                                           stderr=subprocess.STDOUT,
+                                           shell=False, bufsize=1,
+                                           cwd=self.work_dir,
+                                           env=env_variables)
+                start = time.time()
+                stdout = []
+                lines = []
+                for line in iter(process.stdout.readline, b''):
+                    lines.append(line)
+                    stdout.append(line)
+                    if time.time() - start > 30:
+                        queue.post(self.format_message(lines))
+                        lines = []
+                        start = time.time()
+                queue.post(self.format_message(lines))
+                process.stdout.close()
+                returncode = process.wait()
+                # TODO(d0ugal): This bit isn't ideal - as we redirect stderr to
+                # stdout we don't know the difference. To keep the return dict
+                # similar there is an empty stderr. We can use the return code
+                # to determine if there was an error.
+                return {"stdout": "".join(stdout), "returncode": returncode,
+                        "stderr": ""}
+
             stderr, stdout = processutils.execute(
                 *command, cwd=self.work_dir,
                 env_variables=env_variables,
                 log_errors=processutils.LogErrors.ALL)
-            return {"stderr": stderr, "stdout": stdout}
+            return {"stderr": stderr, "stdout": stdout,
+                    "log_path": os.path.join(self.work_dir, 'ansible.log')}
         finally:
             # NOTE(flaper87): clean the mess if debug is disabled.
             if not self.verbosity:
                 shutil.rmtree(self.work_dir)
+
+
+class AnsibleGenerateInventoryAction(actions.Action):
+    """Executes tripleo-ansible-inventory to generate an inventory"""
+
+    def __init__(self, **kwargs):
+        self._kwargs_for_run = kwargs
+        self.ansible_ssh_user = self._kwargs_for_run.pop(
+            'ansible_ssh_user', 'tripleo-admin')
+        self._work_dir = self._kwargs_for_run.pop(
+            'work_dir', None)
+
+    @property
+    def work_dir(self):
+        if self._work_dir:
+            return self._work_dir
+        self._work_dir = tempfile.mkdtemp(prefix='ansible-mistral-action')
+        return self._work_dir
+
+    def run(self, context):
+
+        inventory_path = os.path.join(
+            self.work_dir, 'tripleo-ansible-inventory')
+        command = []
+        command.append('/usr/bin/tripleo-ansible-inventory')
+        command.append('--static-inventory')
+        command.append(inventory_path)
+
+        env_variables = {
+            'HOME': self.work_dir,
+            'OS_AUTH_URL': context.auth_uri,
+            'OS_USERNAME': context.user_name,
+            'OS_AUTH_TOKEN': context.auth_token,
+            'OS_PROJECT_NAME': context.project_name}
+
+        if self.ansible_ssh_user:
+            command.append('--ansible_ssh_user')
+            command.append(self.ansible_ssh_user)
+
+        stderr, stdout = processutils.execute(
+            *command, cwd=self.work_dir,
+            env_variables=env_variables,
+            log_errors=processutils.LogErrors.ALL)
+        return inventory_path
