@@ -18,9 +18,7 @@ import tempfile
 import yaml
 
 from heatclient import exc as heatexceptions
-from keystoneauth1 import exceptions as keystoneauth_exc
 from mistral_lib import actions
-from mistralclient.api import base as mistralclient_base
 from oslo_concurrency import processutils
 import six
 from swiftclient import exceptions as swiftexceptions
@@ -70,53 +68,6 @@ class CreateContainerAction(base.TripleOAction):
         oc.put_container(self.container, headers=default_container_headers)
 
 
-class MigratePlanAction(base.TripleOAction):
-    """Migrate plan from using a Mistral environment to using Swift
-
-    This action creates a plan-environment.yaml file based on the
-    Mistral environment or the default environment, if the file doesn't
-    already exist in Swift.
-
-    This action will be deleted in Queens, as it will no longer be
-    needed by then - all plans will include plan-environment.yaml by
-    default.
-    """
-
-    def __init__(self, plan):
-        super(MigratePlanAction, self).__init__()
-        self.plan = plan
-
-    def run(self, context):
-        swift = self.get_object_client(context)
-        mistral = self.get_workflow_client(context)
-        from_mistral = False
-
-        try:
-            env = plan_utils.get_env(swift, self.plan)
-        except swiftexceptions.ClientException:
-            # The plan has not been migrated yet. Check if there is a
-            # Mistral environment.
-            try:
-                env = mistral.environments.get(self.plan).variables
-                from_mistral = True
-            except (mistralclient_base.APIException,
-                    keystoneauth_exc.http.NotFound):
-                # No Mistral env and no template: likely deploying old
-                # templates aka previous version of OpenStack.
-                env = {'version': 1.0,
-                       'name': self.plan,
-                       'description': '',
-                       'template': 'overcloud.yaml',
-                       'environments': [
-                           {'path': 'overcloud-resource-registry-puppet.yaml'}
-                       ]}
-
-            # Store the environment info into Swift
-            plan_utils.put_env(swift, env)
-            if from_mistral:
-                mistral.environments.delete(self.plan)
-
-
 class ListPlansAction(base.TripleOAction):
     """Lists deployment plans
 
@@ -286,6 +237,10 @@ class UpdatePlanFromDirAction(base.TripleOAction):
                                              '')[1].splitlines()
             old_templates = swift.get_object(self.container,
                                              '')[1].splitlines()
+            exclude_user_data = [constants.PLAN_ENVIRONMENT,
+                                 constants.OVERCLOUD_J2_ROLES_NAME,
+                                 constants.OVERCLOUD_J2_NETWORKS_NAME,
+                                 constants.OVERCLOUD_J2_EXCLUDES]
             # Update the old container
             for new in new_templates:
                 # if doesn't exist, push it:
@@ -298,7 +253,7 @@ class UpdatePlanFromDirAction(base.TripleOAction):
                     content_new = swift.get_object(container_tmp, new)
                     content_old = swift.get_object(self.container, new)
                     if (not content_new == content_old and
-                       constants.PLAN_ENVIRONMENT not in new):
+                       new not in exclude_user_data):
                         swift.put_object(
                             self.container,
                             new,
@@ -309,3 +264,58 @@ class UpdatePlanFromDirAction(base.TripleOAction):
         except Exception as err:
             msg = "Error while updating plan: %s" % err
             return actions.Result(error=msg)
+
+
+class UpdatePlanEnvironmentAction(base.TripleOAction):
+    """Updates the plan environment values
+
+    Updates a plan environment values with the given parameters:
+        Add new parameter
+        Delete parameter
+
+    :param parameter: key value of the parameter to add or delete
+    :param value: value of the parameter to add or delete
+    :param delete: True if the parameter should be deleted from the env
+    :param env_key: environment key that should be one of the keys present
+                    in the plan environment dictionary:
+                         'passwords',
+                         'description',
+                         'parameter_defaults',
+                         'environments',
+                         'version',
+                         'template',
+                         'resource_registry',
+                         'name'
+    :param container: name of the Swift container / plan name
+    """
+
+    def __init__(self, parameter, env_key, value=None, delete=False,
+                 container=constants.DEFAULT_CONTAINER_NAME):
+        super(UpdatePlanEnvironmentAction, self).__init__()
+        self.container = container
+        self.parameter = parameter
+        self.value = value
+        self.delete = delete
+        self.env_key = env_key
+
+    def run(self, context):
+        try:
+            swift = self.get_object_client(context)
+            plan_env = plan_utils.get_env(swift, self.container)
+            if self.env_key in plan_env.keys():
+                if self.delete:
+                    try:
+                        plan_env[self.env_key].pop(self.parameter)
+                    except KeyError:
+                        pass
+                else:
+                    plan_env[self.env_key].update({self.parameter: self.value})
+            else:
+                msg = "The environment key doesn't exist: %s" % self.env_key
+                return actions.Result(error=msg)
+        except swiftexceptions.ClientException as err:
+            msg = "Error attempting an operation on container: %s" % err
+            return actions.Result(error=msg)
+        except Exception as err:
+            msg = "Error while updating plan: %s" % err
+            return actions.Result(error=msg)
