@@ -16,6 +16,8 @@
 import json
 import mock
 import os
+from six.moves import configparser
+import tempfile
 
 from oslo_concurrency import processutils
 
@@ -35,18 +37,23 @@ class AnsibleActionTest(base.TestCase):
         self.become_user = 'root'
         self.ctx = mock.MagicMock()
 
+    @mock.patch("tripleo_common.actions.ansible.write_default_ansible_cfg")
     @mock.patch("oslo_concurrency.processutils.execute")
-    def test_run(self, mock_execute):
+    def test_run(self, mock_execute, mock_write_cfg):
 
         mock_execute.return_value = ('', '')
 
         action = ansible.AnsibleAction(
             hosts=self.hosts, module=self.module, remote_user=self.remote_user,
             become=self.become, become_user=self.become_user)
+        ansible_config_path = os.path.join(action.work_dir, 'ansible.cfg')
+        mock_write_cfg.return_value = ansible_config_path
+
         action.run(self.ctx)
 
         env = {
-            'HOME': action.work_dir
+            'HOME': action.work_dir,
+            'ANSIBLE_CONFIG': ansible_config_path
         }
 
         mock_execute.assert_called_once_with(
@@ -72,8 +79,9 @@ class AnsiblePlaybookActionTest(base.TestCase):
         self.verbosity = 1
         self.ctx = mock.MagicMock()
 
+    @mock.patch("tripleo_common.actions.ansible.write_default_ansible_cfg")
     @mock.patch("oslo_concurrency.processutils.execute")
-    def test_run(self, mock_execute):
+    def test_run(self, mock_execute, mock_write_cfg):
 
         mock_execute.return_value = ('', '')
 
@@ -82,12 +90,15 @@ class AnsiblePlaybookActionTest(base.TestCase):
             remote_user=self.remote_user, become=self.become,
             become_user=self.become_user, extra_vars=self.extra_vars,
             verbosity=self.verbosity)
+        ansible_config_path = os.path.join(action.work_dir, 'ansible.cfg')
+        mock_write_cfg.return_value = ansible_config_path
+
         action.run(self.ctx)
 
         pb = os.path.join(action.work_dir, 'playbook.yaml')
-
         env = {
-            'HOME': action.work_dir
+            'HOME': action.work_dir,
+            'ANSIBLE_CONFIG': ansible_config_path
         }
 
         mock_execute.assert_called_once_with(
@@ -96,3 +107,31 @@ class AnsiblePlaybookActionTest(base.TestCase):
             '--extra-vars', json.dumps(self.extra_vars),
             env_variables=env, cwd=action.work_dir,
             log_errors=processutils.LogErrors.ALL)
+
+
+class CopyConfigFileTest(base.TestCase):
+
+    def test_copy_config_file(self):
+        with tempfile.NamedTemporaryFile() as ansible_cfg_file:
+            ansible_cfg_path = ansible_cfg_file.name
+            work_dir = tempfile.mkdtemp(prefix='ansible-mistral-action-test')
+            # Needed for the configparser to be able to read this file.
+            ansible_cfg_file.write(b'[defaults]\n')
+            ansible_cfg_file.write(b'[ssh_connection]\n')
+            ansible_cfg_file.flush()
+
+            resulting_ansible_config = ansible.write_default_ansible_cfg(
+                work_dir, base_ansible_cfg=ansible_cfg_path)
+
+            self.assertEqual(resulting_ansible_config,
+                             os.path.join(work_dir, 'ansible.cfg'))
+
+        config = configparser.ConfigParser()
+        config.read(resulting_ansible_config)
+
+        retry_files_enabled = config.get('defaults', 'retry_files_enabled')
+        self.assertEqual(retry_files_enabled, 'False')
+
+        log_path = config.get('defaults', 'log_path')
+        self.assertEqual(log_path,
+                         os.path.join(work_dir, 'ansible.log'))
